package com.starry.admin.modules.system.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.starry.admin.modules.system.module.entity.SysRoleEntity;
import com.starry.admin.modules.system.module.entity.SysUserRoleEntity;
import java.util.List;
import java.util.Set;

/**
 * <p>
 * 角色表 服务类
 * </p>
 *
 * @author admin
 * @since 2022-07-01
 */
public interface SysRoleService extends IService<SysRoleEntity> {

    /**
     * 根据roleId 查询角色
     *
     * @param roleId
     *            角色ID
     * @return 角色
     */
    SysRoleEntity selectByRoleId(String roleId);

    /**
     * 根据roleKey 查询角色
     *
     * @param roleKey
     *            角色标识
     * @return 角色
     */
    SysRoleEntity selectByRoleKey(String roleKey);
    /**
     * 校验角色名称是否唯一
     *
     * @param role
     *            角色信息
     * @return 结果
     */
    String checkRoleNameUnique(SysRoleEntity role);

    /**
     * 校验角色权限是否唯一
     *
     * @param role
     *            角色信息
     * @return 结果
     */
    String checkRoleKeyUnique(SysRoleEntity role);

    /**
     * 添加角色
     *
     * @param role
     * @return boolean
     **/
    boolean create(SysRoleEntity role);

    /**
     * 修改角色
     *
     * @param role
     * @return boolean
     **/
    boolean updateRole(SysRoleEntity role);

    /**
     * 通过角色ID查询角色使用数量
     *
     * @param roleId
     *            角色ID
     * @return 结果
     */
    int countUserRoleByRoleId(Long roleId);

    /**
     * 批量删除角色
     *
     * @param roleIds
     * @return boolean
     **/
    boolean delete(Long[] roleIds);

    /**
     * 分页获取角色列表
     *
     * @param keyword
     * @param pageSize
     * @param pageNum
     * @return Page
     **/
    Page<SysRoleEntity> list(String keyword, Integer pageSize, Integer pageNum);

    /**
     * 分配菜单权限信息
     *
     * @param role
     *            角色信息
     * @return 结果
     */
    boolean authRoleMenu(SysRoleEntity role);

    /**
     * 根据用户ID查询角色权限
     *
     * @param userId
     *            用户ID
     * @return 权限列表
     */
    Set<String> selectRolePermissionByUserId(String userId);

    /**
     * 根据条件分页查询角色数据
     *
     * @param role
     *            角色信息
     * @return 角色数据集合信息
     */
    List<SysRoleEntity> selectRoleList(SysRoleEntity role);

    /**
     * 校验角色是否允许操作
     *
     * @param role
     *            角色信息
     */
    void checkRoleAllowed(SysRoleEntity role);

    /**
     * 校验角色是否有数据权限
     *
     * @param roleId
     *            角色id
     */
    void checkRoleDataScope(Long roleId);

    /**
     * 修改数据权限信息
     *
     * @param role
     *            角色信息
     * @return 结果
     */
    int authDataScope(SysRoleEntity role);

    /**
     * 取消授权用户角色
     *
     * @param userRole
     *            用户和角色关联信息
     * @return 结果
     */
    int deleteAuthUser(SysUserRoleEntity userRole);

    /**
     * 批量取消授权用户角色
     *
     * @param roleId
     *            角色ID
     * @param userIds
     *            需要取消授权的用户数据ID
     * @return 结果
     */
    int deleteAuthUsers(Long roleId, String[] userIds);

    /**
     * 批量选择授权用户角色
     *
     * @param roleId
     *            角色ID
     * @param userIds
     *            需要删除的用户数据ID
     * @return 结果
     */
    int insertAuthUsers(Long roleId, String[] userIds);
}
